<?php

class WPML_HyperDB_Requirements {
	private $missing = array();

	public function __construct() {
		$this->init();
	}

	protected function init() {
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded_action' ), PHP_INT_MAX );
		add_action( 'admin_notices', array( $this, 'missing_plugins_warning' ) );
	}

	private function check_required_plugins() {
		$this->missing = array();

		if ( ! defined( 'ICL_SITEPRESS_VERSION' ) || ICL_PLUGIN_INACTIVE ) {
			$this->missing['WPML'] = array(
				'url'  => 'https://wpml.org',
				'slug' => 'sitepress-multilingual-cms',
			);
		}

		if ( ! class_exists( 'hyperdb' ) ) {
			$this->missing['HyperDB'] = array(
				'url'  => 'https://wordpress.org/plugins/hyperdb/',
				'slug' => 'hyperdb',
			);
		}
	}

	public function plugins_loaded_action() {
		$this->check_required_plugins();

		if ( ! $this->missing ) {
			do_action( 'wpml_hyperdb_has_requirements' );
		}
	}

	public function missing_plugins_warning() {
		if ( $this->missing ) {
			$missing       = '';
			$missing_slugs = array();
			$counter       = 0;
			foreach ( $this->missing as $title => $data ) {
				$url             = $data['url'];
				$missing_slugs[] = 'wpml-missing-' . sanitize_title_with_dashes( $data['slug'] );
				$counter ++;
				if ( count( $this->missing ) === $counter ) {
					$sep = '';
				} elseif ( count( $this->missing ) - 1 === $counter ) {
					$sep = ' ' . __( 'and', 'wpml-hyperdb' ) . ' ';
				} else {
					$sep = ', ';
				}
				$missing .= '<a href="' . $url . '" target="_blank">' . $title . '</a>' . $sep;
			}

			$missing_slugs_classes = implode( ' ', $missing_slugs );
			?>
			<div class="message error wpml-admin-notice wpml-hyperdb-inactive <?php echo esc_attr( $missing_slugs_classes ); ?>">
				<p>
					<?php
					/* translators: Plugin requirement message. 1: Plugin name */
					echo wp_kses_post( sprintf( __( 'WPML HyperDB is enabled but not effective. It requires %s in order to work.', 'wpml-hyperdb' ), $missing ) );
					?>
				</p>
			</div>
			<?php
		}
	}
}
